==> nfpm-2.31.0.tar.gz: nfpm-2.31.0/README.md <==
<p align="center">
  <img alt="GoReleaser Logo" src="https://avatars2.githubusercontent.com/u/24697112?v=3&s=200" height="140" />
  <h3 align="center">nFPM</h3>
  <p align="center">nFPM is a simple, 0-dependencies, deb, rpm and apk packager.</p>
  <p align="center">
    <a href="https://github.com/goreleaser/nfpm/releases/latest"><img alt="Release" src="https://img.shields.io/github/release/goreleaser/nfpm.svg?style=for-the-badge"></a>
    <a href="/LICENSE.md"><img alt="Software License" src="https://img.shields.io/badge/license-MIT-brightgreen.svg?style=for-the-badge"></a>
    <a href="https://github.com/goreleaser/nfpm/actions?workflow=build"><img alt="GitHub Actions" src="https://img.shields.io/github/actions/workflow/status/goreleaser/nfpm/build.yml?style=for-the-badge&branch=main"></a>
    <a href="https://codecov.io/gh/goreleaser/nfpm"><img alt="Codecov branch" src="https://img.shields.io/codecov/c/github/goreleaser/nfpm/main.svg?style=for-the-badge"></a>
    <a href="https://goreportcard.com/report/github.com/goreleaser/nfpm"><img alt="Go Report Card" src="https://goreportcard.com/badge/github.com/goreleaser/nfpm?style=for-the-badge"></a>
    <a href="https://pkg.go.dev/github.com/goreleaser/nfpm/v2"><img alt="Go Doc" src="https://img.shields.io/badge/godoc-reference-blue.svg?style=for-the-badge"></a>
    <a href="https://github.com/goreleaser"><img alt="Powered By: GoReleaser" src="https://img.shields.io/badge/powered%20by-goreleaser-green.svg?style=for-the-badge"></a>
  </p>
</p>

## Why

While [fpm][] is great, for me, it is a bummer that it depends on `ruby`, `tar`
and other software.

I wanted something that could be used as a binary and/or as a library and that
was really simple.

So I created nFPM: a simpler, 0-dependency, as-little-assumptions-as-possible alternative to fpm.

## Usage

Check the documentation at https://nfpm.goreleaser.com

## Special thanks 🙏

Thanks to the [fpm][] authors for fpm, which inspires nfpm a lot.

## Community

You have questions, need support and or just want to talk about GoReleaser/nFPM?

Here are ways to get in touch with the GoReleaser community:

[![Join Discord](https://img.shields.io/badge/Join_our_Discord_server-5865F2?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/RGEBtg8vQ6)
[![Follow Twitter](https://img.shields.io/badge/follow_on_twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/goreleaser)
[![GitHub Discussions](https://img.shields.io/badge/GITHUB_DISCUSSION-181717?style=for-the-badge&logo=github&logoColor=white)](https://github.com/goreleaser/nfpm/discussions)

## Donate

Donations are very much appreciated! You can donate/sponsor on the main
[goreleaser opencollective](https://opencollective.com/goreleaser)! It's
easy and will surely help the developers at least buy some ☕️ or 🍺!

## Stargazers over time

[![goreleaser/nfpm stargazers over time](https://starchart.cc/goreleaser/nfpm.svg)](https://starchart.cc/goreleaser/nfpm)

---

[fpm]: https://github.com/jordansissel/fpm

==> nfpm-2.38.0.tar.gz: nfpm-2.38.0/README.md <==
<p align="center">
  <img alt="GoReleaser Logo" src="https://becker.software/nfpm.png" height="140" />
  <p align="center">
    <a href="https://github.com/goreleaser/nfpm/releases/latest"><img alt="Release" src="https://img.shields.io/github/release/goreleaser/nfpm.svg?style=for-the-badge"></a>
    <a href="/LICENSE.md"><img alt="Software License" src="https://img.shields.io/badge/license-MIT-brightgreen.svg?style=for-the-badge"></a>
    <a href="https://github.com/goreleaser/nfpm/actions?workflow=build"><img alt="GitHub Actions" src="https://img.shields.io/github/actions/workflow/status/goreleaser/nfpm/build.yml?style=for-the-badge&branch=main"></a>
    <a href="https://codecov.io/gh/goreleaser/nfpm"><img alt="Codecov branch" src="https://img.shields.io/codecov/c/github/goreleaser/nfpm/main.svg?style=for-the-badge"></a>
    <a href="https://goreportcard.com/report/github.com/goreleaser/nfpm"><img alt="Go Report Card" src="https://goreportcard.com/badge/github.com/goreleaser/nfpm?style=for-the-badge"></a>
    <a href="https://pkg.go.dev/github.com/goreleaser/nfpm/v2"><img alt="Go Doc" src="https://img.shields.io/badge/godoc-reference-blue.svg?style=for-the-badge"></a>
    <a href="https://github.com/goreleaser"><img alt="Powered By: GoReleaser" src="https://img.shields.io/badge/powered%20by-goreleaser-green.svg?style=for-the-badge"></a>
  </p>
</p>

## Why

While [fpm][] is great, for me, it is a bummer that it depends on `ruby`, `tar`
and other software.

I wanted something that could be used as a binary and/or as a library and that
was really simple.

So I created nFPM: a simpler, 0-dependency, as-little-assumptions-as-possible alternative to fpm.

## Usage

Check the documentation at https://nfpm.goreleaser.com

## Special thanks 🙏

Thanks to the [fpm][] authors for fpm, which inspires nfpm a lot.

## Community

You have questions, need support and or just want to talk about GoReleaser/nFPM?

Here are ways to get in touch with the GoReleaser community:

[![Join Discord](https://img.shields.io/badge/Join_our_Discord_server-5865F2?style=for-the-badge&logo=discord&logoColor=white)](https://discord.gg/RGEBtg8vQ6)
[![Follow Twitter](https://img.shields.io/badge/follow_on_twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/goreleaser)
[![GitHub Discussions](https://img.shields.io/badge/GITHUB_DISCUSSION-181717?style=for-the-badge&logo=github&logoColor=white)](https://github.com/goreleaser/nfpm/discussions)

## Donate

Donations are very much appreciated! You can donate/sponsor on the main
[goreleaser opencollective](https://opencollective.com/goreleaser)! It's
easy and will surely help the developers at least buy some ☕️ or 🍺!

## Stargazers over time

[![Stargazers over time](https://starchart.cc/goreleaser/nfpm.svg?variant=adaptive)](https://starchart.cc/goreleaser/nfpm)

---

[fpm]: https://github.com/jordansissel/fpm
